Security Advisories (4)
CVE-2026-61484 (2026-08-05)

** UNSUPPORTED WHEN ASSIGNED ** Deserialization of Untrusted Data vulnerability in Apache Lucy. This issue affects Apache Lucy: all versions. As this project is retired, we do not plan to release a version that fixes this issue. Users are recommended to find an alternative or restrict access to the instance to trusted users. NOTE: This vulnerability only affects products that are no longer supported by the maintainer.

CVE-2026-61483 (2026-08-05)

Apache Lucy: QueryParser unbounded recursion on deeply-nested query -> C-stack-overflow DoS ** UNSUPPORTED WHEN ASSIGNED ** Uncontrolled Recursion vulnerability in Apache Lucy. This issue affects Apache Lucy: all versions. As this project is retired, we do not plan to release a version that fixes this issue. Users are recommended to find an alternative or restrict access to the instance to trusted users. NOTE: This vulnerability only affects products that are no longer supported by the maintainer.

CVE-2026-61485 (2026-08-05)

Apache Lucy: Freezer/InStream deserialization bomb - unbounded allocation reading an index ** UNSUPPORTED WHEN ASSIGNED ** Uncontrolled Recursion vulnerability in Apache Lucy. This issue affects Apache Lucy: all versions. As this project is retired, we do not plan to release a version that fixes this issue. Users are recommended to find an alternative or restrict access to the instance to trusted users. NOTE: This vulnerability only affects products that are no longer supported by the maintainer.

CVE-2026-61486 (2026-08-05)

Apache Lucy: stack-buffer-overflow in JSON parser error reporter on malformed input ** UNSUPPORTED WHEN ASSIGNED ** Stack-based Buffer Overflow vulnerability in Apache Lucy. This issue affects Apache Lucy: all versions. As this project is retired, we do not plan to release a version that fixes this issue. Users are recommended to find an alternative or restrict access to the instance to trusted users. NOTE: This vulnerability only affects products that are no longer supported by the maintainer.

NAME

Lucy::Analysis::Inversion - A collection of Tokens.

SYNOPSIS

my $result = Lucy::Analysis::Inversion->new;

while (my $token = $inversion->next) {
    $result->append($token);
}

DESCRIPTION

An Inversion is a collection of Token objects which you can add to, then iterate over.

CONSTRUCTORS

new

my $inversion = Lucy::Analysis::Inversion->new(
    $seed,  # optional
);

Create a new Inversion.

  • seed - An initial Token to start things off, which may be undef.

METHODS

append

$inversion->append($token);

Tack a token onto the end of the Inversion.

  • token - A Token.

next

my $token = $inversion->next();

Return the next token in the Inversion until out of tokens.

reset

$inversion->reset();

Reset the Inversion’s iterator, so that the next call to next() returns the first Token in the inversion.

INHERITANCE

Lucy::Analysis::Inversion isa Clownfish::Obj.